pub struct OutOfRangeFloatError { /* private fields */ }Expand description
Error returned when a float newtype is outside its range bounds.
Implementations
Sourceimpl OutOfRangeFloatError
impl OutOfRangeFloatError
Sourcepub const fn not_comparable(actual: FloatValue) -> Self
pub const fn not_comparable(actual: FloatValue) -> Self
Creates an error for a value that cannot be compared to range bounds.
Sourcepub const fn below_lower_bound(
actual: FloatValue,
lower_bound: FloatValue,
) -> Self
pub const fn below_lower_bound( actual: FloatValue, lower_bound: FloatValue, ) -> Self
Creates an error for a value below the lower bound.
Sourcepub const fn above_upper_bound(
actual: FloatValue,
upper_bound: FloatValue,
) -> Self
pub const fn above_upper_bound( actual: FloatValue, upper_bound: FloatValue, ) -> Self
Creates an error for a value above the upper bound.
Sourcepub const fn actual(&self) -> FloatValue
pub const fn actual(&self) -> FloatValue
Returns the actual value that failed validation.
Sourcepub const fn lower_bound(&self) -> Option<FloatValue>
pub const fn lower_bound(&self) -> Option<FloatValue>
Returns the lower bound that failed.
Sourcepub const fn upper_bound(&self) -> Option<FloatValue>
pub const fn upper_bound(&self) -> Option<FloatValue>
Returns the upper bound that failed.
Sourcepub const fn violation(&self) -> FloatRangeViolation
pub const fn violation(&self) -> FloatRangeViolation
Returns why range validation failed.