pub struct OutOfRangeIntegerError { /* private fields */ }Expand description
Error returned when an integer newtype is outside its range bounds.
Implementations
Sourceimpl OutOfRangeIntegerError
impl OutOfRangeIntegerError
Sourcepub const fn new(actual: IntegerValue) -> Self
pub const fn new(actual: IntegerValue) -> Self
Creates an out-of-range error with the value that failed validation.
Sourcepub const fn with_lower_bound(self, lower_bound: IntegerValue) -> Self
pub const fn with_lower_bound(self, lower_bound: IntegerValue) -> Self
Returns an out-of-range error with the lower bound that failed.
Sourcepub const fn with_upper_bound(self, upper_bound: IntegerValue) -> Self
pub const fn with_upper_bound(self, upper_bound: IntegerValue) -> Self
Returns an out-of-range error with the upper bound that failed.
Sourcepub const fn actual(&self) -> IntegerValue
pub const fn actual(&self) -> IntegerValue
Returns the actual value that failed validation.
Sourcepub const fn lower_bound(&self) -> Option<IntegerValue>
pub const fn lower_bound(&self) -> Option<IntegerValue>
Returns the lower bound that failed when it could be captured losslessly.
Sourcepub const fn upper_bound(&self) -> Option<IntegerValue>
pub const fn upper_bound(&self) -> Option<IntegerValue>
Returns the upper bound that failed when it could be captured losslessly.