pub struct OutOfRangeNumericError { /* private fields */ }Expand description
Error returned when a numeric newtype is outside its range bounds.
Implementations
Sourceimpl OutOfRangeNumericError
impl OutOfRangeNumericError
Sourcepub const fn new(actual: NumericValue) -> Self
pub const fn new(actual: NumericValue) -> Self
Creates an out-of-range error with the value that failed validation.
Sourcepub const fn with_lower_bound(self, lower_bound: NumericValue) -> Self
pub const fn with_lower_bound(self, lower_bound: NumericValue) -> Self
Returns an out-of-range error with the lower bound that failed.
Sourcepub const fn with_upper_bound(self, upper_bound: NumericValue) -> Self
pub const fn with_upper_bound(self, upper_bound: NumericValue) -> Self
Returns an out-of-range error with the upper bound that failed.
Sourcepub const fn actual(&self) -> NumericValue
pub const fn actual(&self) -> NumericValue
Returns the actual value that failed validation.
Sourcepub const fn lower_bound(&self) -> Option<NumericValue>
pub const fn lower_bound(&self) -> Option<NumericValue>
Returns the lower bound that failed when it could be captured losslessly.
Sourcepub const fn upper_bound(&self) -> Option<NumericValue>
pub const fn upper_bound(&self) -> Option<NumericValue>
Returns the upper bound that failed when it could be captured losslessly.